use `ombutel`;

/* IAX Devices */
CREATE TABLE `iaxfriends` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `device_id` int unsigned null default null,
  `trunk_id` int unsigned null default null,
  `name` varchar(40) NOT NULL,
  `description` varchar(255) null default null,
  `type` enum('friend','user','peer') DEFAULT NULL,
  `username` varchar(40) DEFAULT NULL,
  `mailbox` varchar(40) DEFAULT NULL,
  `secret` varchar(100) DEFAULT NULL,
  `dbsecret` varchar(100) DEFAULT NULL,
  `context` varchar(40) DEFAULT NULL,
  `regcontext` varchar(40) DEFAULT NULL,
  `host` varchar(40) DEFAULT NULL,
  `ipaddr` varchar(40) DEFAULT NULL,
  `port` int(11) DEFAULT NULL,
  `defaultip` varchar(20) DEFAULT NULL,
  `sourceaddress` varchar(20) DEFAULT NULL,
  `mask` varchar(20) DEFAULT NULL,
  `regexten` varchar(40) DEFAULT NULL,
  `regseconds` int(11) DEFAULT NULL,
  `accountcode` varchar(80) DEFAULT NULL,
  `mohinterpret` varchar(20) DEFAULT NULL,
  `mohsuggest` varchar(20) DEFAULT NULL,
  `inkeys` varchar(40) DEFAULT NULL,
  `outkeys` varchar(40) DEFAULT NULL,
  `language` varchar(10) DEFAULT NULL,
  `callerid` varchar(100) DEFAULT NULL,
  `cid_number` varchar(40) DEFAULT NULL,
  `sendani` enum('yes','no') DEFAULT NULL,
  `fullname` varchar(40) DEFAULT NULL,
  `trunk` enum('yes','no') DEFAULT NULL,
  `auth` varchar(20) DEFAULT NULL,
  `maxauthreq` int(11) DEFAULT NULL,
  `requirecalltoken` enum('yes','no','auto') DEFAULT NULL,
  `encryption` enum('yes','no','aes128') DEFAULT NULL,
  `transfer` enum('yes','no','mediaonly') DEFAULT NULL,
  `jitterbuffer` enum('yes','no') DEFAULT NULL,
  `forcejitterbuffer` enum('yes','no') DEFAULT NULL,
  `disallow` varchar(200) DEFAULT NULL,
  `allow` varchar(200) DEFAULT NULL,
  `codecpriority` varchar(40) DEFAULT NULL,
  `qualify` varchar(10) DEFAULT NULL,
  `qualifysmoothing` enum('yes','no') DEFAULT NULL,
  `qualifyfreqok` varchar(10) DEFAULT NULL,
  `qualifyfreqnotok` varchar(10) DEFAULT NULL,
  `timezone` varchar(20) DEFAULT NULL,
  `adsi` enum('yes','no') DEFAULT NULL,
  `amaflags` varchar(20) DEFAULT NULL,
  `setvar` varchar(200) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `name` (`name`),
  KEY `iaxfriends_name` (`name`),
  KEY `iaxfriends_name_host` (`name`,`host`),
  KEY `iaxfriends_name_ipaddr_port` (`name`,`ipaddr`,`port`),
  KEY `iaxfriends_ipaddr_port` (`ipaddr`,`port`),
  KEY `iaxfriends_host_port` (`host`,`port`),
  foreign key (`device_id`) references `ombu_devices` (`device_id`) on delete cascade,
  foreign key (`trunk_id`) references `ombu_trunks` (`trunk_id`) on delete cascade
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

/* PJSIP Realtime */
CREATE TABLE `ps_aors` (
    `aor_id` int unsigned not null auto_increment,
   `id` varchar(40) NOT NULL,
   `device_id` int unsigned null default null,
   `trunk_id` int unsigned null default null,
   `contact` text,
   `default_expiration` int(11) DEFAULT NULL,
   `mailboxes` varchar(80) DEFAULT NULL,
   `max_contacts` int(11) DEFAULT NULL,
   `minimum_expiration` int(11) DEFAULT NULL,
   `remove_existing` enum('yes','no') DEFAULT NULL,
   `qualify_frequency` int(11) DEFAULT NULL,
   `authenticate_qualify` enum('yes','no') DEFAULT NULL,
   `maximum_expiration` int(11) DEFAULT NULL,
   `outbound_proxy` varchar(40) DEFAULT NULL,
   `support_path` enum('yes','no') DEFAULT NULL,
   `qualify_timeout` float DEFAULT NULL,
   `voicemail_extension` varchar(40) DEFAULT NULL,
   primary key (`aor_id`),
   UNIQUE KEY `id` (`id`),
   KEY `ps_aors_id` (`id`),
   foreign key (`device_id`) references `ombu_devices` (`device_id`) on delete cascade,
   foreign key (`trunk_id`) references `ombu_trunks` (`trunk_id`) on delete cascade
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_auths` (
    `auth_id` int unsigned not null auto_increment,
    `id` varchar(40) NOT NULL,
    `device_id` int unsigned null default null,
    `trunk_id` int unsigned null default null,
    `auth_type` enum('md5','userpass','google_oauth') DEFAULT NULL,
    `nonce_lifetime` int(11) DEFAULT NULL,
    `md5_cred` varchar(100) DEFAULT NULL,
    `password` varchar(100) DEFAULT NULL,
    `realm` varchar(40) DEFAULT NULL,
    `username` varchar(40) DEFAULT NULL,
    `refresh_token` varchar(255) DEFAULT NULL,
    `oauth_clientid` varchar(255) DEFAULT NULL,
    `oauth_secret` varchar(255) DEFAULT NULL,
    primary key (`auth_id`),
    UNIQUE KEY `id` (`id`),
    KEY `ps_auths_id` (`id`),
    foreign key (`device_id`) references `ombu_devices` (`device_id`) on delete cascade,
    foreign key (`trunk_id`) references `ombu_trunks` (`trunk_id`) on delete cascade
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_contacts` (
   `contact_id` int unsigned not null auto_increment,
   `id` varchar(255) DEFAULT NULL,
   `device_id` int unsigned null default null,
   `trunk_id` int unsigned null default null,
   `uri` varchar(511) DEFAULT NULL,
   `expiration_time` bigint(20) DEFAULT NULL,
   `qualify_frequency` int(11) DEFAULT NULL,
   `outbound_proxy` varchar(40) DEFAULT NULL,
   `path` text,
   `user_agent` varchar(255) DEFAULT NULL,
   `qualify_timeout` float DEFAULT NULL,
   `reg_server` varchar(255) DEFAULT NULL,
   `authenticate_qualify` enum('yes','no') DEFAULT NULL,
   `via_addr` varchar(40) DEFAULT NULL,
   `via_port` int(11) DEFAULT NULL,
   `call_id` varchar(255) DEFAULT NULL,
   `endpoint` varchar(40) DEFAULT NULL,
   `prune_on_boot` enum('yes','no') DEFAULT NULL,
   primary key (`contact_id`),
   UNIQUE KEY `id` (`id`),
   UNIQUE KEY `ps_contacts_uq` (`id`,`reg_server`),
   KEY `ps_contacts_id` (`id`),
   KEY `ps_contacts_qualifyfreq_exp` (`qualify_frequency`,`expiration_time`),
   foreign key (`device_id`) references `ombu_devices` (`device_id`) on delete cascade,
   foreign key (`trunk_id`) references `ombu_trunks` (`trunk_id`) on delete cascade
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_endpoints` (
    `endpoint_id` int unsigned null auto_increment,
    `id` varchar(40) NOT NULL,
    `device_id` int unsigned null default null,
    `trunk_id` int unsigned null default null,
    `transport` varchar(40) DEFAULT NULL,
    `aors` varchar(200) DEFAULT NULL,
    `auth` varchar(40) DEFAULT NULL,
    `context` varchar(40) DEFAULT NULL,
    `disallow` varchar(200) DEFAULT NULL,
    `allow` varchar(200) DEFAULT NULL,
    `direct_media` enum('yes','no') DEFAULT NULL,
    `connected_line_method` enum('invite','reinvite','update') DEFAULT NULL,
    `direct_media_method` enum('invite','reinvite','update') DEFAULT NULL,
    `direct_media_glare_mitigation` enum('none','outgoing','incoming') DEFAULT NULL,
    `disable_direct_media_on_nat` enum('yes','no') DEFAULT NULL,
    `dtmf_mode` enum('rfc4733','inband','info','auto','auto_info') DEFAULT NULL,
    `external_media_address` varchar(40) DEFAULT NULL,
    `force_rport` enum('yes','no') DEFAULT NULL,
    `ice_support` enum('yes','no') DEFAULT NULL,
    `identify_by` varchar(80) DEFAULT NULL,
    `mailboxes` varchar(40) DEFAULT NULL,
    `moh_suggest` varchar(40) DEFAULT NULL,
    `outbound_auth` varchar(40) DEFAULT NULL,
    `outbound_proxy` varchar(40) DEFAULT NULL,
    `rewrite_contact` enum('yes','no') DEFAULT NULL,
    `rtp_ipv6` enum('yes','no') DEFAULT NULL,
    `rtp_symmetric` enum('yes','no') DEFAULT NULL,
    `send_diversion` enum('yes','no') DEFAULT NULL,
    `send_pai` enum('yes','no') DEFAULT NULL,
    `send_rpid` enum('yes','no') DEFAULT NULL,
    `timers_min_se` int(11) DEFAULT NULL,
    `timers` enum('forced','no','required','yes') DEFAULT NULL,
    `timers_sess_expires` int(11) DEFAULT NULL,
    `callerid` varchar(40) DEFAULT NULL,
    `callerid_privacy` enum('allowed_not_screened','allowed_passed_screened','allowed_failed_screened','allowed','prohib_not_screened','prohib_passed_screened','prohib_failed_screened','prohib','unavailable') DEFAULT NULL,
    `callerid_tag` varchar(40) DEFAULT NULL,
    /* `100rel` enum('no','required','yes') DEFAULT NULL, */
    `aggregate_mwi` enum('yes','no') DEFAULT NULL,
    `trust_id_inbound` enum('yes','no') DEFAULT NULL,
    `trust_id_outbound` enum('yes','no') DEFAULT NULL,
    `use_ptime` enum('yes','no') DEFAULT NULL,
    `use_avpf` enum('yes','no') DEFAULT NULL,
    `media_encryption` enum('no','sdes','dtls') DEFAULT NULL,
    `inband_progress` enum('yes','no') DEFAULT NULL,
    `call_group` varchar(40) DEFAULT NULL,
    `pickup_group` varchar(40) DEFAULT NULL,
    `named_call_group` varchar(40) DEFAULT NULL,
    `named_pickup_group` varchar(40) DEFAULT NULL,
    `device_state_busy_at` int(11) DEFAULT NULL,
    `fax_detect` enum('yes','no') DEFAULT NULL,
    `t38_udptl` enum('yes','no') DEFAULT NULL,
    `t38_udptl_ec` enum('none','fec','redundancy') DEFAULT NULL,
    `t38_udptl_maxdatagram` int(11) DEFAULT NULL,
    `t38_udptl_nat` enum('yes','no') DEFAULT NULL,
    `t38_udptl_ipv6` enum('yes','no') DEFAULT NULL,
    `tone_zone` varchar(40) DEFAULT NULL,
    `language` varchar(40) DEFAULT NULL,
    `one_touch_recording` enum('yes','no') DEFAULT NULL,
    `record_on_feature` varchar(40) DEFAULT NULL,
    `record_off_feature` varchar(40) DEFAULT NULL,
    `rtp_engine` varchar(40) DEFAULT NULL,
    `allow_transfer` enum('yes','no') DEFAULT NULL,
    `allow_subscribe` enum('yes','no') DEFAULT NULL,
    `sdp_owner` varchar(40) DEFAULT NULL,
    `sdp_session` varchar(40) DEFAULT NULL,
    `tos_audio` varchar(10) DEFAULT NULL,
    `tos_video` varchar(10) DEFAULT NULL,
    `sub_min_expiry` int(11) DEFAULT NULL,
    `from_domain` varchar(40) DEFAULT NULL,
    `from_user` varchar(40) DEFAULT NULL,
    `mwi_from_user` varchar(40) DEFAULT NULL,
    `dtls_verify` varchar(40) DEFAULT NULL,
    `dtls_rekey` varchar(40) DEFAULT NULL,
    `dtls_cert_file` varchar(200) DEFAULT NULL,
    `dtls_private_key` varchar(200) DEFAULT NULL,
    `dtls_cipher` varchar(200) DEFAULT NULL,
    `dtls_ca_file` varchar(200) DEFAULT NULL,
    `dtls_ca_path` varchar(200) DEFAULT NULL,
    `dtls_setup` enum('active','passive','actpass') DEFAULT NULL,
    `srtp_tag_32` enum('yes','no') DEFAULT NULL,
    `media_address` varchar(40) DEFAULT NULL,
    `redirect_method` enum('user','uri_core','uri_pjsip') DEFAULT NULL,
    `set_var` text,
    `cos_audio` int(11) DEFAULT NULL,
    `cos_video` int(11) DEFAULT NULL,
    `message_context` varchar(40) DEFAULT NULL,
    `force_avp` enum('yes','no') DEFAULT NULL,
    `media_use_received_transport` enum('yes','no') DEFAULT NULL,
    `accountcode` varchar(80) DEFAULT NULL,
    `user_eq_phone` enum('yes','no') DEFAULT NULL,
    `moh_passthrough` enum('yes','no') DEFAULT NULL,
    `media_encryption_optimistic` enum('yes','no') DEFAULT NULL,
    `rpid_immediate` enum('yes','no') DEFAULT NULL,
    `g726_non_standard` enum('yes','no') DEFAULT NULL,
    `rtp_keepalive` int(11) DEFAULT NULL,
    `rtp_timeout` int(11) DEFAULT NULL,
    `rtp_timeout_hold` int(11) DEFAULT NULL,
    `bind_rtp_to_media_address` enum('yes','no') DEFAULT NULL,
    `voicemail_extension` varchar(40) DEFAULT NULL,
    `mwi_subscribe_replaces_unsolicited` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
    `deny` varchar(95) DEFAULT NULL,
    `permit` varchar(95) DEFAULT NULL,
    `acl` varchar(40) DEFAULT NULL,
    `contact_deny` varchar(95) DEFAULT NULL,
    `contact_permit` varchar(95) DEFAULT NULL,
    `contact_acl` varchar(40) DEFAULT NULL,
    `subscribe_context` varchar(40) DEFAULT NULL,
    `fax_detect_timeout` int(11) DEFAULT NULL,
    `contact_user` varchar(80) DEFAULT NULL,
    `preferred_codec_only` enum('yes','no') DEFAULT NULL,
    `asymmetric_rtp_codec` enum('yes','no') DEFAULT NULL,
    `rtcp_mux` enum('yes','no') DEFAULT NULL,
    `allow_overlap` enum('yes','no') DEFAULT NULL,
    `refer_blind_progress` enum('yes','no') DEFAULT NULL,
    `notify_early_inuse_ringing` enum('yes','no') DEFAULT NULL,
    `max_audio_streams` int(11) DEFAULT NULL,
    `max_video_streams` int(11) DEFAULT NULL,
    `webrtc` enum('yes','no') DEFAULT NULL,
    `dtls_fingerprint` enum('SHA-1','SHA-256') DEFAULT NULL,
    `incoming_mwi_mailbox` varchar(40) DEFAULT NULL,
    `bundle` enum('yes','no') DEFAULT NULL,
    `dtls_auto_generate_cert` enum('yes','no') DEFAULT NULL,
    `follow_early_media_fork` enum('yes','no') DEFAULT NULL,
    `accept_multiple_sdp_answers` enum('yes','no') DEFAULT NULL,
    `suppress_q850_reason_headers` enum('yes','no') DEFAULT NULL,
    `trust_connected_line` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
    `send_connected_line` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
    `ignore_183_without_sdp` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
    `codec_prefs_incoming_offer` varchar(128) DEFAULT NULL,
    `codec_prefs_outgoing_offer` varchar(128) DEFAULT NULL,
    `codec_prefs_incoming_answer` varchar(128) DEFAULT NULL,
    `codec_prefs_outgoing_answer` varchar(128) DEFAULT NULL,
    `stir_shaken` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
    `send_history_info` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
    primary key (`endpoint_id`),
    UNIQUE KEY `id` (`id`),
    KEY `ps_endpoints_id` (`id`),
    foreign key (`device_id`) references `ombu_devices` (`device_id`) on delete cascade,
    foreign key (`trunk_id`) references `ombu_trunks` (`trunk_id`) on delete cascade
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_globals` (
  `id` varchar(40) NOT NULL,
  `max_forwards` int(11) DEFAULT NULL,
  `user_agent` varchar(255) DEFAULT NULL,
  `default_outbound_endpoint` varchar(40) DEFAULT NULL,
  `debug` varchar(40) DEFAULT NULL,
  `endpoint_identifier_order` varchar(40) DEFAULT NULL,
  `max_initial_qualify_time` int(11) DEFAULT NULL,
  `default_from_user` varchar(80) DEFAULT NULL,
  `keep_alive_interval` int(11) DEFAULT NULL,
  `regcontext` varchar(80) DEFAULT NULL,
  `contact_expiration_check_interval` int(11) DEFAULT NULL,
  `default_voicemail_extension` varchar(40) DEFAULT NULL,
  `disable_multi_domain` enum('yes','no') DEFAULT NULL,
  `unidentified_request_count` int(11) DEFAULT NULL,
  `unidentified_request_period` int(11) DEFAULT NULL,
  `unidentified_request_prune_interval` int(11) DEFAULT NULL,
  `default_realm` varchar(40) DEFAULT NULL,
  `mwi_tps_queue_high` int(11) DEFAULT NULL,
  `mwi_tps_queue_low` int(11) DEFAULT NULL,
  `mwi_disable_initial_unsolicited` enum('yes','no') DEFAULT NULL,
  `ignore_uri_user_options` enum('yes','no') DEFAULT NULL,
  `use_callerid_contact` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
  `send_contact_status_on_update_registration` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
  `taskprocessor_overload_trigger` enum('none','global','pjsip_only') DEFAULT NULL,
  `norefersub` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
  UNIQUE KEY `id` (`id`),
  KEY `ps_globals_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_registrations` (
    `registration_id` int unsigned not null auto_increment,
    `id` varchar(40) NOT NULL,
    `device_id` int unsigned null default null,
    `trunk_id` int unsigned null default null,
    `auth_rejection_permanent` enum('yes','no') DEFAULT NULL,
    `client_uri` varchar(255) DEFAULT NULL,
    `contact_user` varchar(40) DEFAULT NULL,
    `expiration` int(11) DEFAULT NULL,
    `max_retries` int(11) DEFAULT NULL,
    `outbound_auth` varchar(40) DEFAULT NULL,
    `outbound_proxy` varchar(40) DEFAULT NULL,
    `retry_interval` int(11) DEFAULT NULL,
    `forbidden_retry_interval` int(11) DEFAULT NULL,
    `server_uri` varchar(255) DEFAULT NULL,
    `transport` varchar(40) DEFAULT NULL,
    `support_path` enum('yes','no') DEFAULT NULL,
    `fatal_retry_interval` int(11) DEFAULT NULL,
    `line` enum('yes','no') DEFAULT NULL,
    `endpoint` varchar(40) DEFAULT NULL,
    `support_outbound` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
    `contact_header_params` varchar(255) DEFAULT NULL,
    primary key (`registration_id`),
    UNIQUE KEY `id` (`id`),
    KEY `ps_registrations_id` (`id`),
    foreign key (`device_id`) references `ombu_devices` (`device_id`) on delete cascade,
    foreign key (`trunk_id`) references `ombu_trunks` (`trunk_id`) on delete cascade
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_endpoint_id_ips` (
    `identify_id` int unsigned not null auto_increment,
    `id` varchar(40) NOT NULL,
    `device_id` int unsigned null default null,
    `trunk_id` int unsigned null default null,
    `endpoint` varchar(40) DEFAULT NULL,
    `match` text,
    `srv_lookups` enum('yes','no') DEFAULT NULL,
    `match_header` varchar(255) DEFAULT NULL,
    primary key (`identify_id`),
    UNIQUE KEY `id` (`id`),
    KEY `ps_endpoint_id_ips_id` (`id`),
    foreign key (`device_id`) references `ombu_devices` (`device_id`) on delete cascade,
    foreign key (`trunk_id`) references `ombu_trunks` (`trunk_id`) on delete cascade
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_systems` (
  `id` varchar(40) NOT NULL,
  `timer_t1` int(11) DEFAULT NULL,
  `timer_b` int(11) DEFAULT NULL,
  `compact_headers` enum('yes','no') DEFAULT NULL,
  `threadpool_initial_size` int(11) DEFAULT NULL,
  `threadpool_auto_increment` int(11) DEFAULT NULL,
  `threadpool_idle_timeout` int(11) DEFAULT NULL,
  `threadpool_max_size` int(11) DEFAULT NULL,
  `disable_tcp_switch` enum('yes','no') DEFAULT NULL,
  `follow_early_media_fork` enum('yes','no') DEFAULT NULL,
  `accept_multiple_sdp_answers` enum('yes','no') DEFAULT NULL,
  `disable_rport` enum('0','1','off','on','false','true','no','yes') DEFAULT NULL,
  UNIQUE KEY `id` (`id`),
  KEY `ps_systems_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_transports` (
     `id` varchar(40) NOT NULL,
     `async_operations` int(11) DEFAULT NULL,
     `bind` varchar(40) DEFAULT NULL,
     `ca_list_file` varchar(200) DEFAULT NULL,
     `cert_file` varchar(200) DEFAULT NULL,
     `cipher` varchar(200) DEFAULT NULL,
     `domain` varchar(40) DEFAULT NULL,
     `external_media_address` varchar(40) DEFAULT NULL,
     `external_signaling_address` varchar(40) DEFAULT NULL,
     `external_signaling_port` int(11) DEFAULT NULL,
     `method` enum('default','unspecified','tlsv1','sslv2','sslv3','sslv23') DEFAULT NULL,
     `local_net` varchar(200) DEFAULT NULL,
     `password` varchar(40) DEFAULT NULL,
     `priv_key_file` varchar(200) DEFAULT NULL,
     `protocol` enum('udp','tcp','tls','ws','wss','flow') DEFAULT NULL,
     `require_client_cert` enum('yes','no') DEFAULT NULL,
     `verify_client` enum('yes','no') DEFAULT NULL,
     `verify_server` enum('yes','no') DEFAULT NULL,
     `tos` varchar(10) DEFAULT NULL,
     `cos` int(11) DEFAULT NULL,
     `allow_reload` enum('yes','no') DEFAULT NULL,
     `symmetric_transport` enum('yes','no') DEFAULT NULL,
     UNIQUE KEY `id` (`id`),
     KEY `ps_transports_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_subscription_persistence` (
   `id` varchar(40) NOT NULL,
   `packet` varchar(2048) DEFAULT NULL,
   `src_name` varchar(128) DEFAULT NULL,
   `src_port` int(11) DEFAULT NULL,
   `transport_key` varchar(64) DEFAULT NULL,
   `local_name` varchar(128) DEFAULT NULL,
   `local_port` int(11) DEFAULT NULL,
   `cseq` int(11) DEFAULT NULL,
   `tag` varchar(128) DEFAULT NULL,
   `endpoint` varchar(40) DEFAULT NULL,
   `expires` int(11) DEFAULT NULL,
   `contact_uri` varchar(256) DEFAULT NULL,
   `prune_on_boot` enum('yes','no') DEFAULT NULL,
   UNIQUE KEY `id` (`id`),
   KEY `ps_subscription_persistence_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_resource_list` (
    `id` varchar(40) NOT NULL,
    `list_item` varchar(2048) DEFAULT NULL,
    `event` varchar(40) DEFAULT NULL,
    `full_state` enum('yes','no') DEFAULT NULL,
    `notification_batch_interval` int(11) DEFAULT NULL,
    UNIQUE KEY `id` (`id`),
    KEY `ps_resource_list_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_outbound_publishes` (
     `id` varchar(40) NOT NULL,
     `expiration` int(11) DEFAULT NULL,
     `outbound_auth` varchar(40) DEFAULT NULL,
     `outbound_proxy` varchar(256) DEFAULT NULL,
     `server_uri` varchar(256) DEFAULT NULL,
     `from_uri` varchar(256) DEFAULT NULL,
     `to_uri` varchar(256) DEFAULT NULL,
     `event` varchar(40) DEFAULT NULL,
     `max_auth_attempts` int(11) DEFAULT NULL,
     `transport` varchar(40) DEFAULT NULL,
     `multi_user` enum('yes','no') DEFAULT NULL,
     `@body` varchar(40) DEFAULT NULL,
     `@context` varchar(256) DEFAULT NULL,
     `@exten` varchar(256) DEFAULT NULL,
     UNIQUE KEY `id` (`id`),
     KEY `ps_outbound_publishes_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_inbound_publications` (
   `id` varchar(40) NOT NULL,
   `endpoint` varchar(40) DEFAULT NULL,
   `event_asterisk-devicestate` varchar(40) DEFAULT NULL,
   `event_asterisk-mwi` varchar(40) DEFAULT NULL,
   UNIQUE KEY `id` (`id`),
   KEY `ps_inbound_publications_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_domain_aliases` (
     `id` varchar(40) NOT NULL,
     `domain` varchar(80) DEFAULT NULL,
     UNIQUE KEY `id` (`id`),
     KEY `ps_domain_aliases_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

CREATE TABLE `ps_asterisk_publications` (
    `id` varchar(40) NOT NULL,
    `devicestate_publish` varchar(40) DEFAULT NULL,
    `mailboxstate_publish` varchar(40) DEFAULT NULL,
    `device_state` enum('yes','no') DEFAULT NULL,
    `device_state_filter` varchar(256) DEFAULT NULL,
    `mailbox_state` enum('yes','no') DEFAULT NULL,
    `mailbox_state_filter` varchar(256) DEFAULT NULL,
    UNIQUE KEY `id` (`id`),
    KEY `ps_asterisk_publications_id` (`id`)
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;

/* SIP Devices*/
CREATE TABLE `sippeers` (
    `id` int(11) NOT NULL AUTO_INCREMENT,
    `device_id` int unsigned null default null,
    `trunk_id` int unsigned null default null,
    `name` varchar(40) NOT NULL,
    `description` varchar(255) null default null,
    `ipaddr` varchar(45) DEFAULT NULL,
    `port` int(11) DEFAULT NULL,
    `regseconds` int(11) DEFAULT NULL,
    `defaultuser` varchar(40) DEFAULT NULL,
    `fullcontact` varchar(80) DEFAULT NULL,
    `regserver` varchar(20) DEFAULT NULL,
    `useragent` varchar(255) DEFAULT NULL,
    `lastms` int(11) DEFAULT NULL,
    `host` varchar(40) DEFAULT NULL,
    `type` enum('friend','user','peer') DEFAULT NULL,
    `context` varchar(40) DEFAULT NULL,
    `deny` varchar(200) DEFAULT NULL,
    `permit` varchar(200) DEFAULT NULL,
    `secret` varchar(100) DEFAULT NULL,
    `md5secret` varchar(100) DEFAULT NULL,
    `remotesecret` varchar(40) DEFAULT NULL,
    `transport` varchar(255) DEFAULT NULL,
    `dtmfmode` enum('rfc2833','info','shortinfo','inband','auto') DEFAULT NULL,
    `directmedia` enum('yes','no','nonat','update','outgoing') DEFAULT NULL,
    `nat` varchar(29) DEFAULT NULL,
    `callgroup` varchar(40) DEFAULT NULL,
    `pickupgroup` varchar(40) DEFAULT NULL,
    `language` varchar(40) DEFAULT NULL,
    `disallow` varchar(200) DEFAULT NULL,
    `allow` varchar(200) DEFAULT NULL,
    `insecure` varchar(40) DEFAULT NULL,
    `trustrpid` enum('yes','no') DEFAULT NULL,
    `progressinband` enum('yes','no','never') DEFAULT NULL,
    `promiscredir` enum('yes','no') DEFAULT NULL,
    `useclientcode` enum('yes','no') DEFAULT NULL,
    `accountcode` varchar(80) DEFAULT NULL,
    `setvar` varchar(200) DEFAULT NULL,
    `callerid` varchar(40) DEFAULT NULL,
    `amaflags` varchar(40) DEFAULT NULL,
    `callcounter` enum('yes','no') DEFAULT NULL,
    `busylevel` int(11) DEFAULT NULL,
    `allowoverlap` enum('yes','no') DEFAULT NULL,
    `allowsubscribe` enum('yes','no') DEFAULT NULL,
    `videosupport` enum('yes','no') DEFAULT NULL,
    `maxcallbitrate` int(11) DEFAULT NULL,
    `rfc2833compensate` enum('yes','no') DEFAULT NULL,
    `mailbox` varchar(40) DEFAULT NULL,
    `session-timers` enum('accept','refuse','originate') DEFAULT NULL,
    `session-expires` int(11) DEFAULT NULL,
    `session-minse` int(11) DEFAULT NULL,
    `session-refresher` enum('uac','uas') DEFAULT NULL,
    `t38pt_usertpsource` varchar(40) DEFAULT NULL,
    `regexten` varchar(40) DEFAULT NULL,
    `fromdomain` varchar(40) DEFAULT NULL,
    `fromuser` varchar(40) DEFAULT NULL,
    `qualify` varchar(40) DEFAULT NULL,
    `defaultip` varchar(45) DEFAULT NULL,
    `rtptimeout` int(11) DEFAULT NULL,
    `rtpholdtimeout` int(11) DEFAULT NULL,
    `sendrpid` enum('yes','no') DEFAULT NULL,
    `outboundproxy` varchar(40) DEFAULT NULL,
    `callbackextension` varchar(40) DEFAULT NULL,
    `timert1` int(11) DEFAULT NULL,
    `timerb` int(11) DEFAULT NULL,
    `qualifyfreq` int(11) DEFAULT NULL,
    `constantssrc` enum('yes','no') DEFAULT NULL,
    `contactpermit` varchar(95) DEFAULT NULL,
    `contactdeny` varchar(95) DEFAULT NULL,
    `usereqphone` enum('yes','no') DEFAULT NULL,
    `textsupport` enum('yes','no') DEFAULT NULL,
    `faxdetect` enum('yes','no') DEFAULT NULL,
    `buggymwi` enum('yes','no') DEFAULT NULL,
    `auth` varchar(40) DEFAULT NULL,
    `fullname` varchar(40) DEFAULT NULL,
    `trunkname` varchar(40) DEFAULT NULL,
    `cid_number` varchar(40) DEFAULT NULL,
    `callingpres` enum('allowed_not_screened','allowed_passed_screen','allowed_failed_screen','allowed','prohib_not_screened','prohib_passed_screen','prohib_failed_screen','prohib') DEFAULT NULL,
    `mohinterpret` varchar(40) DEFAULT NULL,
    `mohsuggest` varchar(40) DEFAULT NULL,
    `parkinglot` varchar(40) DEFAULT NULL,
    `hasvoicemail` enum('yes','no') DEFAULT NULL,
    `subscribemwi` enum('yes','no') DEFAULT NULL,
    `vmexten` varchar(40) DEFAULT NULL,
    `autoframing` enum('yes','no') DEFAULT NULL,
    `rtpkeepalive` int(11) DEFAULT NULL,
    `call-limit` int(11) DEFAULT NULL,
    `g726nonstandard` enum('yes','no') DEFAULT NULL,
    `ignoresdpversion` enum('yes','no') DEFAULT NULL,
    `allowtransfer` enum('yes','no') DEFAULT NULL,
    `dynamic` enum('yes','no') DEFAULT NULL,
    `path` varchar(256) DEFAULT NULL,
    `supportpath` enum('yes','no') DEFAULT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `name` (`name`),
    KEY `sippeers_name` (`name`),
    KEY `sippeers_name_host` (`name`,`host`),
    KEY `sippeers_ipaddr_port` (`ipaddr`,`port`),
    KEY `sippeers_host_port` (`host`,`port`),
    foreign key (`device_id`) references `ombu_devices` (`device_id`) on delete cascade,
    foreign key (`trunk_id`) references `ombu_trunks` (`trunk_id`) on delete cascade
) engine=innodb default charset=utf8 collate=utf8_unicode_ci;